@@ -6,6 +6,7 @@
     :license: MIT, see LICENSE for more details.
 """
 import time
+import warnings
 
 from SoftLayer import auth as slauth
 from SoftLayer import config
@@ -44,6 +45,8 @@ class Client(object):
     :param auth: an object which responds to get_headers() to be inserted into
         the xml-rpc headers. Example: `BasicAuthentication`
     :param config_file: A path to a configuration file used to load settings
+    :param user_agent: an optional User Agent to report when making API
+        calls if you wish to bypass the packages built in User Agent string
 
     Usage:
 
@@ -57,7 +60,8 @@ class Client(object):
     _prefix = "SoftLayer_"
 
     def __init__(self, username=None, api_key=None, endpoint_url=None,
-                 timeout=None, auth=None, config_file=None, proxy=None):
+                 timeout=None, auth=None, config_file=None, proxy=None,
+                 user_agent=None):
 
         settings = config.get_client_settings(username=username,
                                               api_key=api_key,
@@ -75,6 +79,7 @@ class Client(object):
         self.proxy = None
         if settings.get('proxy'):
             self.proxy = settings.get('proxy')
+        self.user_agent = user_agent
 
     def authenticate_with_password(self, username, password,
                                    security_question_id=None,
@@ -140,29 +145,8 @@ class Client(object):
         if not service.startswith(self._prefix):
             service = self._prefix + service
 
-        headers = kwargs.get('headers', {})
-
-        if self.auth:
-            headers.update(self.auth.get_headers())
-
-        if kwargs.get('id') is not None:
-            headers[service + 'InitParameters'] = {'id': kwargs.get('id')}
-
-        if kwargs.get('mask') is not None:
-            headers.update(self.__format_object_mask(kwargs.get('mask'),
-                                                     service))
-
-        if kwargs.get('filter') is not None:
-            headers['%sObjectFilter' % service] = kwargs.get('filter')
-
-        if kwargs.get('limit'):
-            headers['resultLimit'] = {
-                'limit': kwargs.get('limit'),
-                'offset': kwargs.get('offset', 0),
-            }
-
         http_headers = {
-            'User-Agent': consts.USER_AGENT,
+            'User-Agent': self.user_agent or consts.USER_AGENT,
             'Content-Type': 'application/xml',
         }
 
@@ -173,12 +157,31 @@ class Client(object):
         if kwargs.get('raw_headers'):
             http_headers.update(kwargs.get('raw_headers'))
 
-        uri = '/'.join([self.endpoint_url, service])
-        return transports.make_xml_rpc_api_call(uri, method, args,
-                                                headers=headers,
-                                                http_headers=http_headers,
-                                                timeout=self.timeout,
-                                                proxy=self.proxy)
+        request = transports.Request()
+        request.endpoint = self.endpoint_url
+        request.service = service
+        request.method = method
+        request.args = args
+        request.transport_headers = http_headers
+        request.timeout = self.timeout
+        request.proxy = self.proxy
+        request.identifier = kwargs.get('id')
+        request.mask = kwargs.get('mask')
+        request.filter = kwargs.get('filter')
+        request.limit = kwargs.get('limit')
+        request.offset = kwargs.get('offset')
+
+        if self.auth:
+            extra_headers = self.auth.get_headers()
+            if extra_headers:
+                warnings.warn("auth.get_headers() is deprecated and will be "
+                              "removed in the next major version",
+                              DeprecationWarning)
+                request.headers.update(extra_headers)
+
+            request = self.auth.get_request(request)
+
+        return transports.make_xml_rpc_api_call(request)
 
     __call__ = call
 
@@ -233,25 +236,6 @@ class Client(object):
             if len(results) < chunk:
                 break
 
-    def __format_object_mask(self, objectmask, service):
-        """Format new and old style object masks into proper headers.
-
-        :param objectmask: a string- or dict-based object mask
-        :param service: a SoftLayer API service name
-
-        """
-        if isinstance(objectmask, dict):
-            mheader = '%sObjectMask' % service
-        else:
-            mheader = self._prefix + 'ObjectMask'
-
-            objectmask = objectmask.strip()
-            if (not objectmask.startswith('mask')
-                    and not objectmask.startswith('[')):
-                objectmask = "mask[%s]" % objectmask
-
-        return {mheader: {'mask': objectmask}}
-
     def __repr__(self):
         return "<Client: endpoint=%s, user=%r>" % (self.endpoint_url,
                                                    self.auth)
@@ -322,6 +306,8 @@ class Service(object):
         :param int offset: (optional) offset results by this many
         :param boolean iter: (optional) if True, returns a generator with the
                              results
+        :param bool verify: verify SSL cert
+        :param cert: client certificate path
 
         Usage:
             >>> import SoftLayer
