@@ -18,6 +18,7 @@ The available commands are:
   power-on        Boots up a server
   reboot          Reboots a running server
   reload          Perform an OS reload
+  rescue          Reboot server into a rescue image
 
 For several commands, <identifier> will be asked for. This can be the id,
 hostname or the ip address for a piece of hardware.
@@ -88,12 +89,14 @@ For more on filters see 'sl help filters'
             'memory',
             'primary_ip',
             'backend_ip',
-            'active_transaction'
+            'active_transaction',
+            'owner'
         ])
         table.sortby = args.get('--sortby') or 'host'
 
         for server in servers:
             server = utils.NestedDict(server)
+
             table.add_row([
                 server['id'],
                 server['datacenter']['name'] or formatting.blank(),
@@ -103,6 +106,9 @@ For more on filters see 'sl help filters'
                 server['primaryIpAddress'] or formatting.blank(),
                 server['primaryBackendIpAddress'] or formatting.blank(),
                 formatting.active_txn(server),
+                utils.lookup(
+                    server, 'billingItem', 'orderItem', 'order', 'userRecord',
+                    'username') or formatting.blank(),
             ])
 
         return table
@@ -156,10 +162,18 @@ Options:
                 result['operatingSystem']['softwareLicense']
                 ['softwareDescription']['name'] or formatting.blank()
             )])
-        table.add_row(['created',
-                       result['provisionDate'] or formatting.blank()])
+
+        table.add_row(
+            ['created', result['provisionDate'] or formatting.blank()])
+
+        table.add_row(['owner', formatting.FormattedItem(
+            utils.lookup(result, 'billingItem', 'orderItem',
+                         'order', 'userRecord',
+                         'username') or formatting.blank()
+        )])
 
         vlan_table = formatting.Table(['type', 'number', 'id'])
+
         for vlan in result['networkVlans']:
             vlan_table.add_row([
                 vlan['networkSpace'], vlan['vlanNumber'], vlan['id']])
@@ -187,14 +201,16 @@ Options:
             table.add_row(['tags', formatting.listing(tag_row, separator=',')])
 
         # Test to see if this actually has a primary (public) ip address
-        if result['primaryIpAddress']:
-            ptr_domains = (self.client['Hardware_Server']
-                           .getReverseDomainRecords(id=hardware_id))
-
-            for ptr_domain in ptr_domains:
-                for ptr in ptr_domain['resourceRecords']:
-                    table.add_row(['ptr', ptr['data']])
+        try:
+            if not result['privateNetworkOnlyFlag']:
+                ptr_domains = (self.client['Hardware_Server']
+                               .getReverseDomainRecords(id=hardware_id))
 
+                for ptr_domain in ptr_domains:
+                    for ptr in ptr_domain['resourceRecords']:
+                        table.add_row(['ptr', ptr['data']])
+        except SoftLayer.SoftLayerAPIError:
+            pass
         return table
 
 
@@ -237,6 +253,8 @@ usage: sl server cancel <identifier> [options]
 Cancel a dedicated server
 
 Options:
+  --immediate        Cancels the server immediately (instead of on the billing
+                       anniversary)
   --comment=COMMENT  An optional comment to add to the cancellation ticket
   --reason=REASON    An optional cancellation reason. See cancel-reasons for a
                        list of available options
@@ -256,9 +274,10 @@ Options:
             comment = self.env.input("(Optional) Add a cancellation comment:")
 
         reason = args.get('--reason')
+        immediate = args.get('--immediate')
 
         if args['--really'] or formatting.no_going_back(hw_id):
-            mgr.cancel_hardware(hw_id, reason, comment)
+            mgr.cancel_hardware(hw_id, reason, comment, immediate)
         else:
             raise exceptions.CLIAbort('Aborted')
 
@@ -424,6 +443,32 @@ Display a list of chassis available for ordering dedicated servers.
         return table
 
 
+class ServerRescue(environment.CLIRunnable):
+    """
+usage: sl server rescue <identifier> [options]
+
+Reboot server into a rescue image
+
+
+"""
+    action = 'rescue'
+    options = ['confirm']
+
+    def execute(self, args):
+        server = SoftLayer.HardwareManager(self.client)
+        server_id = helpers.resolve_id(server.resolve_ids,
+                                       args.get('<identifier>'),
+                                       'hardware')
+
+        if args['--really'] or formatting.confirm(
+                "This action will reboot this server. "
+                "Continue?"):
+
+            server.rescue(server_id)
+        else:
+            raise exceptions.CLIAbort('Aborted')
+
+
 class ServerCreateOptions(environment.CLIRunnable):
     """
 usage: sl server create-options <chassis_id> [options]
