@@ -1,18 +1,5 @@
 """
-usage: sl summary [options]
-
-Display summary information about the account
-"""
-# :license: MIT, see LICENSE for more details.
-
-import SoftLayer
-from SoftLayer.CLI import environment
-from SoftLayer.CLI import formatting
-
-
-class Summary(environment.CLIRunnable):
-    """
-usage: sl summary [options]
+usage: sl summary [<command>] [<args>...] [options]
 
 Display summary information about the account
 
@@ -20,6 +7,16 @@ Options:
   --sortby=ARG  Column to sort by. options: datacenter, vlans,
                 subnets, IPs, networking, hardware, vs
 """
+# :license: MIT, see LICENSE for more details.
+# pylint: disable=missing-docstring
+
+import SoftLayer
+from SoftLayer.CLI import environment
+from SoftLayer.CLI import formatting
+
+
+class Summary(environment.CLIRunnable):
+    __doc__ = __doc__
     action = None
 
     def execute(self, args):
