@@ -20,6 +20,7 @@ The available commands are:
   ready           Check if a virtual server has finished provisioning
   reboot          Reboots a running virtual server
   reload          Reload the OS on a VS based on its current configuration
+  rescue          Reboot server into a rescue image
   resume          Resumes a paused virtual server
   upgrade         Upgrades parameters of a virtual server
 
@@ -93,7 +94,7 @@ For more on filters see 'sl help filters'
         table = formatting.Table([
             'id', 'datacenter', 'host',
             'cores', 'memory', 'primary_ip',
-            'backend_ip', 'active_transaction',
+            'backend_ip', 'active_transaction', 'owner'
         ])
         table.sortby = args.get('--sortby') or 'host'
 
@@ -108,6 +109,8 @@ For more on filters see 'sl help filters'
                 guest['primaryIpAddress'] or formatting.blank(),
                 guest['primaryBackendIpAddress'] or formatting.blank(),
                 formatting.active_txn(guest),
+                utils.lookup(guest, 'billingItem', 'orderItem', 'order',
+                             'userRecord', 'username') or formatting.blank(),
             ])
 
         return table
@@ -173,6 +176,11 @@ Options:
         table.add_row(['private_cpu', result['dedicatedAccountHostOnlyFlag']])
         table.add_row(['created', result['createDate']])
         table.add_row(['modified', result['modifyDate']])
+        table.add_row(['owner', formatting.FormattedItem(
+            utils.lookup(result, 'billingItem', 'orderItem',
+                         'order', 'userRecord',
+                         'username') or formatting.blank(),
+        )])
 
         vlan_table = formatting.Table(['type', 'number', 'id'])
         for vlan in result['networkVlans']:
@@ -201,13 +209,16 @@ Options:
             table.add_row(['tags', formatting.listing(tag_row, separator=',')])
 
         # Test to see if this actually has a primary (public) ip address
-        if result['primaryIpAddress']:
-            ptr_domains = (self.client['Virtual_Guest']
-                           .getReverseDomainRecords(id=vs_id))
+        try:
+            if not result['privateNetworkOnlyFlag']:
+                ptr_domains = (self.client['Virtual_Guest']
+                               .getReverseDomainRecords(id=vs_id))
 
-            for ptr_domain in ptr_domains:
-                for ptr in ptr_domain['resourceRecords']:
-                    table.add_row(['ptr', ptr['data']])
+                for ptr_domain in ptr_domains:
+                    for ptr in ptr_domain['resourceRecords']:
+                        table.add_row(['ptr', ptr['data']])
+        except SoftLayer.SoftLayerAPIError:
+            pass
 
         return table
 
@@ -366,6 +377,7 @@ Optional:
   --test                 Do not create VS, just get a quote
   --export=FILE          Exports options to a template file
   -F, --userfile=FILE    Read userdata from file
+  -g --tag=TAG           Comma list of tags to set
   -i, --postinstall=URI  Post-install script to download
                            (Only HTTPS executes, HTTP leaves file in /root)
   -k, --key=KEY          SSH keys to add to the root user. Can be specified
@@ -533,6 +545,11 @@ Optional:
                 '--private': like_details['privateNetworkOnlyFlag'],
             }
 
+            tag_refs = like_details.get('tagReferences', None)
+            if tag_refs is not None and len(tag_refs) > 0:
+                tags = ','.join([t['tag']['name'] for t in tag_refs])
+                like_args['--tag'] = tags
+
             # Handle mutually exclusive options
             like_image = utils.lookup(like_details,
                                       'blockDeviceTemplateGroup',
@@ -564,6 +581,7 @@ Optional:
 
         :param dict args: CLI arguments
         """
+        args = helpers.sanitize_args(args)
         data = {
             "hourly": args['--hourly'],
             "cpus": args['--cpu'],
@@ -628,10 +646,14 @@ Optional:
         if args.get('--vlan_private'):
             data['private_vlan'] = args['--vlan_private']
 
+        if args.get('--tag'):
+            data['tag'] = args['--tag']
+
         return data
 
 
 class ReadyVS(environment.CLIRunnable):
+
     """
 usage: sl vs ready <identifier> [options]
 
@@ -853,6 +875,31 @@ Options:
         vsi.change_port_speed(vs_id, public, args['--speed'])
 
 
+class VSRescue(environment.CLIRunnable):
+    """
+usage: sl vs rescue <identifier> [options]
+
+Reboot into Xen rescue image
+
+
+"""
+    action = 'rescue'
+    options = ['confirm']
+
+    def execute(self, args):
+        vsi = SoftLayer.VSManager(self.client)
+        vs_id = helpers.resolve_id(vsi.resolve_ids,
+                                   args.get('<identifier>'),
+                                   'VS')
+        if args['--really'] or formatting.confirm(
+                "This action will reboot this VSI. "
+                "Continue?"):
+
+            vsi.rescue(vs_id)
+        else:
+            raise exceptions.CLIAbort('Aborted')
+
+
 class VSDNS(environment.CLIRunnable):
     """
 usage: sl vs dns sync <identifier> [options]
@@ -970,6 +1017,7 @@ Edit a virtual server's details
 Options:
   -D --domain=DOMAIN  Domain portion of the FQDN example: example.com
   -F --userfile=FILE  Read userdata from file
+  -g --tag=TAG        Comma list of tags to set or empty string to remove all
   -H --hostname=HOST  Host portion of the FQDN. example: server
   -u --userdata=DATA  User defined metadata string
 """
@@ -995,6 +1043,7 @@ Options:
 
         data['hostname'] = args.get('--hostname')
         data['domain'] = args.get('--domain')
+        data['tag'] = args.get("--tag")
 
         vsi = SoftLayer.VSManager(self.client)
         vs_id = helpers.resolve_id(vsi.resolve_ids,
@@ -1056,7 +1105,7 @@ usage: sl vs upgrade <identifier> [options]
 Upgrade parameters of a virtual server
 
 Examples:
-    sl vs upgrade --cpus 2
+    sl vs upgrade --cpu 2
     sl vs upgrade --memory 2048 --network 1000
 Options:
     --cpu=CPU          Number of CPU cores
