@@ -33,7 +33,8 @@ class HardwareManager(utils.IdentifierMixin, object):
         else:
             self.ordering_manager = ordering_manager
 
-    def cancel_hardware(self, hardware_id, reason='unneeded', comment=''):
+    def cancel_hardware(self, hardware_id, reason='unneeded', comment='',
+                        immediate=False):
         """ Cancels the specified dedicated server.
 
         :param int hardware_id: The ID of the hardware to be cancelled.
@@ -48,7 +49,7 @@ class HardwareManager(utils.IdentifierMixin, object):
                                    mask='id,bareMetalInstanceFlag')
 
         if server.get('bareMetalInstanceFlag'):
-            return self.cancel_metal(hardware_id)
+            return self.cancel_metal(hardware_id, immediate)
 
         reasons = self.get_cancellation_reasons()
         cancel_reason = reasons['unneeded']
@@ -121,6 +122,7 @@ class HardwareManager(utils.IdentifierMixin, object):
                 'primaryBackendIpAddress',
                 'primaryIpAddress',
                 'datacenter',
+                'billingItem.orderItem.order.userRecord[username]',
             ]
             server_items = [
                 'activeTransaction[id, transactionStatus[friendlyName,name]]',
@@ -210,7 +212,8 @@ class HardwareManager(utils.IdentifierMixin, object):
         ordering_manager = self.ordering_manager
 
         mask = 'id,name,description,type,isActive'
-        package_types = ['BARE_METAL_CPU', 'BARE_METAL_CORE']
+        package_types = ['BARE_METAL_CPU',
+                         'BARE_METAL_CORE']
 
         packages = ordering_manager.get_packages_of_type(package_types,
                                                          mask)
@@ -223,7 +226,7 @@ class HardwareManager(utils.IdentifierMixin, object):
 
         for package in packages:
             available_packages.append((package['id'], package['name'],
-                                       package['description']))
+                                       package.get('description', None)))
 
         return available_packages
 
@@ -291,6 +294,7 @@ class HardwareManager(utils.IdentifierMixin, object):
                 'hourlyBillingFlag',
                 'tagReferences[id,tag[name,id]]',
                 'networkVlans[id,vlanNumber,networkSpace]',
+                'billingItem.orderItem.order.userRecord[username]',
             ]
             kwargs['mask'] = "mask[%s]" % ','.join(items)
 
@@ -316,6 +320,13 @@ class HardwareManager(utils.IdentifierMixin, object):
         return self.hardware.reloadOperatingSystem('FORCE', config,
                                                    id=hardware_id)
 
+    def rescue(self, hardware_id):
+        """ Reboot a server into the a recsue kernel
+
+        :param integer instance_id: the server ID to rescue
+        """
+        return self.hardware.bootToRescueLayer(id=hardware_id)
+
     def change_port_speed(self, hardware_id, public, speed):
         """ Allows you to change the port speed of a server's NICs.
 
