@@ -15,6 +15,7 @@ from SoftLayer import utils
 
 
 class VSManager(utils.IdentifierMixin, object):
+
     """
     Manages Virtual Servers
 
@@ -24,6 +25,7 @@ class VSManager(utils.IdentifierMixin, object):
                                               If none is provided, one will be
                                               auto initialized.
     """
+
     def __init__(self, client, ordering_manager=None):
         self.client = client
         self.account = client['Account']
@@ -86,6 +88,7 @@ class VSManager(utils.IdentifierMixin, object):
                 'datacenter',
                 'activeTransaction.transactionStatus[friendlyName,name]',
                 'status',
+                'billingItem.orderItem.order.userRecord[username]'
             ]
             kwargs['mask'] = "mask[%s]" % ','.join(items)
 
@@ -199,6 +202,7 @@ class VSManager(utils.IdentifierMixin, object):
                 'billingItem.recurringFee',
                 'tagReferences[id,tag[name,id]]',
                 'networkVlans[id,vlanNumber,networkSpace]',
+                'billingItem.orderItem.order.userRecord[username]'
             ]
             kwargs['mask'] = "mask[%s]" % ','.join(items)
 
@@ -452,8 +456,13 @@ class VSManager(utils.IdentifierMixin, object):
                              access to the private network. Defaults to false
         :param list ssh_keys: The SSH keys to add to the root user
         :param int nic_speed: The port speed to set
+        :param string tag: tags to set on the VS as a comma separated list
         """
-        return self.guest.createObject(self._generate_create_dict(**kwargs))
+        tags = kwargs.pop('tags', None)
+        inst = self.guest.createObject(self._generate_create_dict(**kwargs))
+        if tags is not None:
+            self.guest.setTags(tags, id=inst['id'])
+        return inst
 
     def create_instances(self, config_list):
         """ Creates multiple virtual server instances
@@ -461,9 +470,17 @@ class VSManager(utils.IdentifierMixin, object):
         This takes a list of dictionaries using the same arguments as
         create_instance().
         """
-        return self.guest.createObjects([self._generate_create_dict(**kwargs)
+        tags = [conf.pop('tags', None) for conf in config_list]
+
+        resp = self.guest.createObjects([self._generate_create_dict(**kwargs)
                                          for kwargs in config_list])
 
+        for instance, tag in zip(resp, tags):
+            if tag is not None:
+                self.guest.setTags(tag, id=instance['id'])
+
+        return resp
+
     def change_port_speed(self, instance_id, public, speed):
         """ Allows you to change the port speed of a virtual server's NICs.
 
@@ -503,7 +520,7 @@ class VSManager(utils.IdentifierMixin, object):
             return [result['id'] for result in results]
 
     def edit(self, instance_id, userdata=None, hostname=None, domain=None,
-             notes=None):
+             notes=None, tag=None):
         """ Edit hostname, domain name, notes, and/or the user data of a VS
 
         Parameters set to None will be ignored and not attempted to be updated.
@@ -514,6 +531,8 @@ class VSManager(utils.IdentifierMixin, object):
         :param string hostname: valid hostname
         :param string domain: valid domain namem
         :param string notes: notes about this particular VS
+        :param string tag: tags to set on the VS as a comma separated list.
+                            Use the empty string to remove all tags.
 
         """
 
@@ -521,6 +540,9 @@ class VSManager(utils.IdentifierMixin, object):
         if userdata:
             self.guest.setUserMetadata([userdata], id=instance_id)
 
+        if tag is not None:
+            self.guest.setTags(tag, id=instance_id)
+
         if hostname:
             obj['hostname'] = hostname
 
@@ -535,6 +557,13 @@ class VSManager(utils.IdentifierMixin, object):
 
         return self.guest.editObject(obj, id=instance_id)
 
+    def rescue(self, instance_id):
+        """ Reboot a VSI into the Xen recsue kernel
+
+        :param integer instance_id: the instance ID to rescue
+        """
+        return self.guest.executeRescueLayer(id=instance_id)
+
     def capture(self, instance_id, name, additional_disks=False, notes=None):
         """ Capture one or all disks from a VS to a SoftLayer image.
 
@@ -610,10 +639,10 @@ class VSManager(utils.IdentifierMixin, object):
         """
         Following Method gets all the item ids related to VS
         """
-        mask = "mask[description,capacity,prices.id,categories[name,id]]"
+        mask = "mask[description,capacity,prices[id,categories[name,id]]]"
         package_type = "VIRTUAL_SERVER_INSTANCE"
         package_id = self.ordering_manager.get_package_id_by_type(package_type)
-        package_service = self.ordering_manager.get_package_service()
+        package_service = self.client['Product_Package']
 
         return package_service.getItems(id=package_id, mask=mask)
 
@@ -628,8 +657,9 @@ class VSManager(utils.IdentifierMixin, object):
         """
         vs_id = {'memory': 3, 'cpus': 80, 'nic_speed': 26}
         for item in package_items:
-            for j in range(len(item['categories'])):
-                if not (item['categories'][j]['id'] == vs_id[option] and
+            categories = item['prices'][0]['categories']
+            for j in range(len(categories)):
+                if not (categories[j]['id'] == vs_id[option] and
                         item['capacity'] == str(value)):
                     continue
                 if option == 'cpus':
