@@ -234,7 +234,8 @@ class ServerCLITests(testing.TestCase):
             'tags': ['test_tag'],
             'users': ['root abc123'],
             'vlans': [{'id': 9653, 'number': 1800, 'type': 'PRIVATE'},
-                      {'id': 19082, 'number': 3672, 'type': 'PUBLIC'}]
+                      {'id': 19082, 'number': 3672, 'type': 'PUBLIC'}],
+            'owner': 'chechu'
         }
 
         self.assertEqual(expected, formatting.format_output(output, 'python'))
@@ -242,7 +243,7 @@ class ServerCLITests(testing.TestCase):
     def test_server_details_issue_332(self):
         runnable = server.ServerDetails(client=self.client)
         result = fixtures.Hardware_Server.getObject.copy()
-        result['primaryIpAddress'] = None
+        result['privateNetworkOnlyFlag'] = True
         self.client['Hardware_Server'].getObject.return_value = result
 
         runnable.execute({'<identifier>': 1234,
@@ -266,7 +267,8 @@ class ServerCLITests(testing.TestCase):
                 'cores': 2,
                 'id': 1000,
                 'backend_ip': '10.1.0.2',
-                'active_transaction': 'TXN_NAME'
+                'active_transaction': 'TXN_NAME',
+                'owner': 'chechu'
             },
             {
                 'datacenter': 'TEST00',
@@ -276,7 +278,8 @@ class ServerCLITests(testing.TestCase):
                 'cores': 4,
                 'id': 1001,
                 'backend_ip': '10.1.0.3',
-                'active_transaction': None
+                'active_transaction': None,
+                'owner': 'chechu'
             },
             {
                 'datacenter': 'TEST00',
@@ -286,7 +289,8 @@ class ServerCLITests(testing.TestCase):
                 'cores': 4,
                 'id': 1002,
                 'backend_ip': '10.1.0.4',
-                'active_transaction': None
+                'active_transaction': None,
+                'owner': 'chechu'
             }
         ]
 
@@ -325,7 +329,7 @@ class ServerCLITests(testing.TestCase):
         args = {'--really': True, '--reason': 'Test'}
         runnable.execute(args)
 
-        cancel_mock.assert_called_with(hw_id, args['--reason'], None)
+        cancel_mock.assert_called_with(hw_id, args['--reason'], None, None)
 
         # Now check to make sure we properly call CLIAbort in the negative case
         env_mock = mock.Mock()
