@@ -6,12 +6,14 @@
 """
 from SoftLayer import auth
 from SoftLayer import testing
+from SoftLayer import transports
 
 
 class TestAuthenticationBase(testing.TestCase):
-    def test_get_headers(self):
+    def test_get_request(self):
         auth_base = auth.AuthenticationBase()
-        self.assertRaises(NotImplementedError, auth_base.get_headers)
+        self.assertEqual(auth_base.get_request({}), {})
+        self.assertEqual(auth_base.get_headers(), {})
 
 
 class TestBasicAuthentication(testing.TestCase):
@@ -22,8 +24,10 @@ class TestBasicAuthentication(testing.TestCase):
         self.assertEqual(self.auth.username, 'USERNAME')
         self.assertEqual(self.auth.api_key, 'APIKEY')
 
-    def test_get_headers(self):
-        self.assertEqual(self.auth.get_headers(), {
+    def test_get_request(self):
+        req = transports.Request()
+        authed_req = self.auth.get_request(req)
+        self.assertEqual(authed_req.headers, {
             'authenticate': {
                 'username': 'USERNAME',
                 'apiKey': 'APIKEY',
@@ -44,8 +48,10 @@ class TestTokenAuthentication(testing.TestCase):
         self.assertEqual(self.auth.user_id, 12345)
         self.assertEqual(self.auth.auth_token, 'TOKEN')
 
-    def test_get_headers(self):
-        self.assertEqual(self.auth.get_headers(), {
+    def test_get_request(self):
+        req = transports.Request()
+        authed_req = self.auth.get_request(req)
+        self.assertEqual(authed_req.headers, {
             'authenticate': {
                 'complexType': 'PortalLoginToken',
                 'userId': 12345,
