@@ -8,6 +8,7 @@ import os
 
 import SoftLayer
 from SoftLayer import testing
+from SoftLayer import transports
 
 
 def get_creds():
@@ -34,13 +35,18 @@ class UnauthedUser(testing.TestCase):
 
     def test_no_hostname(self):
         try:
+            request = transports.Request()
+            request.endpoint = 'http://notvalidsoftlayer.com'
+            request.service = 'SoftLayer_Account'
+            request.method = 'getObject'
+            request.id = 1234
+
             # This test will fail if 'notvalidsoftlayer.com' becomes a thing
-            SoftLayer.transports.make_xml_rpc_api_call(
-                'http://notvalidsoftlayer.com', 'getObject')
-        except SoftLayer.SoftLayerAPIError as e:
-            self.assertEqual(e.faultCode, 0)
-            self.assertIn('not known', e.faultString)
-            self.assertIn('not known', e.reason)
+            transports.make_xml_rpc_api_call(request)
+        except SoftLayer.SoftLayerAPIError as ex:
+            self.assertIn('not known', str(ex))
+            self.assertIn('not known', ex.faultString)
+            self.assertEqual(ex.faultCode, 0)
         else:
             self.fail('No Exception Raised')
 
