@@ -45,12 +45,12 @@ class LoadBalancerTests(testing.TestCase):
         f.assert_called_once()
 
     def test_get_location(self):
-        id1 = self.lb_mgr.get_location('sjc01')
+        id1 = self.lb_mgr._get_location('sjc01')
         f = self.client['Location'].getDataCenters
         f.assert_called_once()
         self.assertEqual(id1, 168642)
 
-        id2 = self.lb_mgr.get_location('dal05')
+        id2 = self.lb_mgr._get_location('dal05')
         f = self.client['Location'].getDataCenters
         f.assert_called_once()
         self.assertEqual(id2, 'FIRST_AVAILABLE')
@@ -88,7 +88,7 @@ class LoadBalancerTests(testing.TestCase):
     def test_get_local_lbs(self):
         self.lb_mgr.get_local_lbs()
         call = self.client['Account'].getAdcLoadBalancers
-        mask = ('mask[loadBalancerHardware[datacenter],ipAddress]')
+        mask = 'mask[loadBalancerHardware[datacenter],ipAddress]'
         call.assert_called_once_with(mask=mask)
 
     def test_get_local_lb(self):
@@ -97,11 +97,11 @@ class LoadBalancerTests(testing.TestCase):
         call = self.client['Network_Application_Delivery_Controller_'
                            'LoadBalancer_VirtualIpAddress'].getObject
 
-        mask = ('mask[loadBalancerHardware[datacenter], '
+        mask = ('loadBalancerHardware[datacenter], '
                 'ipAddress, virtualServers[serviceGroups'
                 '[routingMethod,routingType,services'
                 '[healthChecks[type], groupReferences,'
-                ' ipAddress]]]]')
+                ' ipAddress]]]')
         call.assert_called_once_with(id=lb_id, mask=mask)
 
     def test_delete_service(self):
@@ -151,7 +151,7 @@ class LoadBalancerTests(testing.TestCase):
                 }
             }
         }
-        mask = 'mask[serviceGroups[services[groupReferences,healthChecks]]]'
+        mask = 'serviceGroups[services[groupReferences,healthChecks]]'
         call.assert_called_once_with(filter=_filter, mask=mask, id=loadbal_id)
 
         call = self.client['Network_Application_Delivery_Controller_'
@@ -194,8 +194,7 @@ class LoadBalancerTests(testing.TestCase):
         call = self.client['Network_Application_Delivery_Controller_'
                            'LoadBalancer_VirtualIpAddress'].getObject
 
-        mask = ('mask[virtualServers[serviceGroups'
-                '[services[groupReferences]]]]')
+        mask = 'virtualServers[serviceGroups[services[groupReferences]]]'
         call.assert_called_once_with(mask=mask, id=loadbal_id)
 
         call = self.client['Network_Application_Delivery_Controller_'
@@ -213,8 +212,7 @@ class LoadBalancerTests(testing.TestCase):
         call = self.client['Network_Application_Delivery_Controller_'
                            'LoadBalancer_VirtualIpAddress'].getObject
 
-        mask = ('mask[virtualServers[serviceGroups'
-                '[services[groupReferences]]]]')
+        mask = 'virtualServers[serviceGroups[services[groupReferences]]]'
         call.assert_called_once_with(mask=mask, id=loadbal_id)
 
         call = self.client['Network_Application_Delivery_Controller_'
@@ -229,8 +227,9 @@ class LoadBalancerTests(testing.TestCase):
                            'LoadBalancer_VirtualIpAddress'].getVirtualServers
 
         _filter = {'virtualServers': {'id': {'operation': group_id}}}
-        mask = 'mask[serviceGroups]'
-        call.assert_called_once_with(filter=_filter, mask=mask, id=loadbal_id)
+        call.assert_called_once_with(filter=_filter,
+                                     mask='serviceGroups',
+                                     id=loadbal_id)
 
         call = self.client['Network_Application_Delivery_Controller_'
                            'LoadBalancer_Service_Group'].kickAllConnections
