@@ -137,16 +137,20 @@ class VSTests(testing.TestCase):
     @mock.patch('SoftLayer.managers.vs.VSManager._generate_create_dict')
     def test_create_instance(self, create_dict):
         create_dict.return_value = {'test': 1, 'verify': 1}
-        self.vs.create_instance(test=1, verify=1)
+        self.vs.create_instance(test=1, verify=1, tags='dev,green')
+
         create_dict.assert_called_once_with(test=1, verify=1)
         self.client['Virtual_Guest'].createObject.assert_called_once_with(
             {'test': 1, 'verify': 1})
+        self.client['Virtual_Guest'].setTags.assert_called_once_with(
+            'dev,green', id=100)
 
     def test_create_instances(self):
         self.vs.create_instances([{'cpus': 1,
                                    'memory': 1024,
                                    'hostname': 'server',
-                                   'domain': 'example.com'}])
+                                   'domain': 'example.com',
+                                   'tags': 'dev,green'}])
         self.client['Virtual_Guest'].createObjects.assert_called_once_with([
             {'domain': 'example.com',
              'hourlyBillingFlag': True,
@@ -154,6 +158,8 @@ class VSTests(testing.TestCase):
              'maxMemory': 1024, 'hostname':
              'server',
              'startCpus': 1}])
+        self.client['Virtual_Guest'].setTags.assert_called_once_with(
+            'dev,green', id=100)
 
     def test_generate_os_and_image(self):
         self.assertRaises(
@@ -511,6 +517,15 @@ class VSTests(testing.TestCase):
         f = service.setPrivateNetworkInterfaceSpeed
         f.assert_called_once_with(speed, id=vs_id)
 
+    def test_rescue(self):
+        # Test rescue environment
+        vs_id = 1234
+        self.vs.rescue(vs_id)
+
+        service = self.client['Virtual_Guest']
+        f = service.executeRescueLayer
+        f.assert_called_once_with(id=vs_id)
+
     def test_edit(self):
         # Test editing user data
         service = self.client['Virtual_Guest']
@@ -532,6 +547,13 @@ class VSTests(testing.TestCase):
         self.vs.edit(100, **args)
         service.editObject.assert_called_once_with(args, id=100)
 
+        # Test tag support
+        self.vs.edit(100, tag='dev,green')
+        service.setTags.assert_called_once_with('dev,green', id=100)
+        service.setTags.reset_mock()
+        self.vs.edit(100, tag='')
+        service.setTags.assert_called_once_with('', id=100)
+
     def test_captures(self):
         archive = self.client['Virtual_Guest'].createArchiveTransaction
 
@@ -574,7 +596,7 @@ class VSTests(testing.TestCase):
         item_id = 0
         package_items = self.client['Product_Package'].getItems(id=46)
         for item in package_items:
-            if ((item['categories'][0]['id'] == 3)
+            if ((item['prices'][0]['categories'][0]['id'] == 3)
                     and (item.get('capacity') == '2')):
                 item_id = item['prices'][0]['id']
                 break
